==> celestine-2024.6.9-py3-none-any.whl: celestine/literal.py <==
"""Central place for text strings."""

NONE = ""
NULL = chr(0)
START_OF_HEADING = chr(1)
START_OF_TEXT = chr(2)
END_OF_TEXT = chr(3)
END_OF_TRANSMISSION = chr(4)
ENQUIRY = chr(5)
ACKNOWLEDGE = chr(6)
BELL = chr(7)
BACKSPACE = chr(8)
CHARACTER_TABULATION = chr(9)
LINE_FEED = chr(10)
LINE_TABULATION = chr(11)
FORM_FEED = chr(12)
CARRIAGE_RETURN = chr(13)
SHIFT_OUT = chr(14)
SHIFT_IN = chr(15)
DATA_LINK_ESCAPE = chr(16)
DEVICE_CONTROL_ONE = chr(17)
DEVICE_CONTROL_TWO = chr(18)
DEVICE_CONTROL_THREE = chr(19)
DEVICE_CONTROL_FOUR = chr(20)
NEGATIVE_ACKNOWLEDGE = chr(21)
SYNCHRONOUS_IDLE = chr(22)
END_OF_TRANSMISSION_BLOCK = chr(23)
CANCEL = chr(24)
END_OF_MEDIUM = chr(25)
SUBSTITUTE = chr(26)
ESCAPE = chr(27)
INFORMATION_SEPARATOR_FOUR = chr(28)
INFORMATION_SEPARATOR_THREE = chr(29)
INFORMATION_SEPARATOR_TWO = chr(30)
INFORMATION_SEPARATOR_ONE = chr(31)
SPACE = chr(32)
EXCLAMATION_MARK = chr(33)
QUOTATION_MARK = chr(34)
NUMBER_SIGN = chr(35)
DOLLAR_SIGN = chr(36)
PERCENT_SIGN = chr(37)
AMPERSAND = chr(38)
APOSTROPHE = chr(39)
LEFT_PARENTHESIS = chr(40)
RIGHT_PARENTHESIS = chr(41)
ASTERISK = chr(42)
PLUS_SIGN = chr(43)
COMMA = chr(44)
HYPHEN_MINUS = chr(45)
FULL_STOP = chr(46)
SOLIDUS = chr(47)
DIGIT_ZERO = chr(48)
DIGIT_ONE = chr(49)
DIGIT_TWO = chr(50)
DIGIT_THREE = chr(51)
DIGIT_FOUR = chr(52)
DIGIT_FIVE = chr(53)
DIGIT_SIX = chr(54)
DIGIT_SEVEN = chr(55)
DIGIT_EIGHT = chr(56)
DIGIT_NINE = chr(57)
COLON = chr(58)
SEMICOLON = chr(59)
LESS_THAN_SIGN = chr(60)
EQUALS_SIGN = chr(61)
GREATER_THAN_SIGN = chr(62)
QUESTION_MARK = chr(63)
COMMERCIAL_AT = chr(64)
LATIN_CAPITAL_LETTER_A = chr(65)
LATIN_CAPITAL_LETTER_B = chr(66)
LATIN_CAPITAL_LETTER_C = chr(67)
LATIN_CAPITAL_LETTER_D = chr(68)
LATIN_CAPITAL_LETTER_E = chr(69)
LATIN_CAPITAL_LETTER_F = chr(70)
LATIN_CAPITAL_LETTER_G = chr(71)
LATIN_CAPITAL_LETTER_H = chr(72)
LATIN_CAPITAL_LETTER_I = chr(73)
LATIN_CAPITAL_LETTER_J = chr(74)
LATIN_CAPITAL_LETTER_K = chr(75)
LATIN_CAPITAL_LETTER_L = chr(76)
LATIN_CAPITAL_LETTER_M = chr(77)
LATIN_CAPITAL_LETTER_N = chr(78)
LATIN_CAPITAL_LETTER_O = chr(79)
LATIN_CAPITAL_LETTER_P = chr(80)
LATIN_CAPITAL_LETTER_Q = chr(81)
LATIN_CAPITAL_LETTER_R = chr(82)
LATIN_CAPITAL_LETTER_S = chr(83)
LATIN_CAPITAL_LETTER_T = chr(84)
LATIN_CAPITAL_LETTER_U = chr(85)
LATIN_CAPITAL_LETTER_V = chr(86)
LATIN_CAPITAL_LETTER_W = chr(87)
LATIN_CAPITAL_LETTER_X = chr(88)
LATIN_CAPITAL_LETTER_Y = chr(89)
LATIN_CAPITAL_LETTER_Z = chr(90)
LEFT_SQUARE_BRACKET = chr(91)
REVERSE_SOLIDUS = chr(92)
RIGHT_SQUARE_BRACKET = chr(93)
CIRCUMFLEX_ACCENT = chr(94)
LOW_LINE = chr(95)
GRAVE_ACCENT = chr(96)
LATIN_SMALL_LETTER_A = chr(97)
LATIN_SMALL_LETTER_B = chr(98)
LATIN_SMALL_LETTER_C = chr(99)
LATIN_SMALL_LETTER_D = chr(100)
LATIN_SMALL_LETTER_E = chr(101)
LATIN_SMALL_LETTER_F = chr(102)
LATIN_SMALL_LETTER_G = chr(103)
LATIN_SMALL_LETTER_H = chr(104)
LATIN_SMALL_LETTER_I = chr(105)
LATIN_SMALL_LETTER_J = chr(106)
LATIN_SMALL_LETTER_K = chr(107)
LATIN_SMALL_LETTER_L = chr(108)
LATIN_SMALL_LETTER_M = chr(109)
LATIN_SMALL_LETTER_N = chr(110)
LATIN_SMALL_LETTER_O = chr(111)
LATIN_SMALL_LETTER_P = chr(112)
LATIN_SMALL_LETTER_Q = chr(113)
LATIN_SMALL_LETTER_R = chr(114)
LATIN_SMALL_LETTER_S = chr(115)
LATIN_SMALL_LETTER_T = chr(116)
LATIN_SMALL_LETTER_U = chr(117)
LATIN_SMALL_LETTER_V = chr(118)
LATIN_SMALL_LETTER_W = chr(119)
LATIN_SMALL_LETTER_X = chr(120)
LATIN_SMALL_LETTER_Y = chr(121)
LATIN_SMALL_LETTER_Z = chr(122)
LEFT_CURLY_BRACKET = chr(123)
VERTICAL_LINE = chr(124)
RIGHT_CURLY_BRACKET = chr(125)
TILDE = chr(126)
DELETE = chr(127)


def join(*iterable: str) -> str:
    """"""
    return NONE.join(iterable)


FUNCTION = join(
    LESS_THAN_SIGN,
    LATIN_SMALL_LETTER_F,
    LATIN_SMALL_LETTER_U,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_N,
    SPACE,
)
INIT = join(
    LOW_LINE,
    LOW_LINE,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_T,
    LOW_LINE,
    LOW_LINE,
)
PYTHON_EXTENSION = join(
    FULL_STOP,
    LATIN_SMALL_LETTER_P,
    LATIN_SMALL_LETTER_Y,
)
########################################################################
APPLICATION = join(
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_P,
    LATIN_SMALL_LETTER_P,
    LATIN_SMALL_LETTER_L,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_N,
)
BLENDER = join(
    LATIN_SMALL_LETTER_B,
    LATIN_SMALL_LETTER_L,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_D,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_R,
)
CELESTINE = join(
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_L,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_S,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_E,
)
CONFIGURATION = join(
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_F,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_G,
    LATIN_SMALL_LETTER_U,
    LATIN_SMALL_LETTER_R,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_N,
)
DIRECTORY = join(
    LATIN_SMALL_LETTER_D,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_R,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_R,
    LATIN_SMALL_LETTER_Y,
)
INTERFACE = join(
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_R,
    LATIN_SMALL_LETTER_F,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_E,
)
LANGUAGE = join(
    LATIN_SMALL_LETTER_L,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_G,
    LATIN_SMALL_LETTER_U,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_G,
    LATIN_SMALL_LETTER_E,
)
PACKAGE = join(
    LATIN_SMALL_LETTER_P,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_K,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_G,
    LATIN_SMALL_LETTER_E,
)

########################################################################
VERSION_NUMBER = "2024.6.9"

==> celestine-2025.2.17-py3-none-any.whl: celestine/literal.py <==
"""Central place for text strings."""

from celestine.typed import string

NONE = ""
NULL = chr(0)
START_OF_HEADING = chr(1)
START_OF_TEXT = chr(2)
END_OF_TEXT = chr(3)
END_OF_TRANSMISSION = chr(4)
ENQUIRY = chr(5)
ACKNOWLEDGE = chr(6)
BELL = chr(7)
BACKSPACE = chr(8)
CHARACTER_TABULATION = chr(9)
LINE_FEED = chr(10)
LINE_TABULATION = chr(11)
FORM_FEED = chr(12)
CARRIAGE_RETURN = chr(13)
SHIFT_OUT = chr(14)
SHIFT_IN = chr(15)
DATA_LINK_ESCAPE = chr(16)
DEVICE_CONTROL_ONE = chr(17)
DEVICE_CONTROL_TWO = chr(18)
DEVICE_CONTROL_THREE = chr(19)
DEVICE_CONTROL_FOUR = chr(20)
NEGATIVE_ACKNOWLEDGE = chr(21)
SYNCHRONOUS_IDLE = chr(22)
END_OF_TRANSMISSION_BLOCK = chr(23)
CANCEL = chr(24)
END_OF_MEDIUM = chr(25)
SUBSTITUTE = chr(26)
ESCAPE = chr(27)
INFORMATION_SEPARATOR_FOUR = chr(28)
INFORMATION_SEPARATOR_THREE = chr(29)
INFORMATION_SEPARATOR_TWO = chr(30)
INFORMATION_SEPARATOR_ONE = chr(31)
SPACE = chr(32)
EXCLAMATION_MARK = chr(33)
QUOTATION_MARK = chr(34)
NUMBER_SIGN = chr(35)
DOLLAR_SIGN = chr(36)
PERCENT_SIGN = chr(37)
AMPERSAND = chr(38)
APOSTROPHE = chr(39)
LEFT_PARENTHESIS = chr(40)
RIGHT_PARENTHESIS = chr(41)
ASTERISK = chr(42)
PLUS_SIGN = chr(43)
COMMA = chr(44)
HYPHEN_MINUS = chr(45)
FULL_STOP = chr(46)
SOLIDUS = chr(47)
DIGIT_ZERO = chr(48)
DIGIT_ONE = chr(49)
DIGIT_TWO = chr(50)
DIGIT_THREE = chr(51)
DIGIT_FOUR = chr(52)
DIGIT_FIVE = chr(53)
DIGIT_SIX = chr(54)
DIGIT_SEVEN = chr(55)
DIGIT_EIGHT = chr(56)
DIGIT_NINE = chr(57)
COLON = chr(58)
SEMICOLON = chr(59)
LESS_THAN_SIGN = chr(60)
EQUALS_SIGN = chr(61)
GREATER_THAN_SIGN = chr(62)
QUESTION_MARK = chr(63)
COMMERCIAL_AT = chr(64)
LATIN_CAPITAL_LETTER_A = chr(65)
LATIN_CAPITAL_LETTER_B = chr(66)
LATIN_CAPITAL_LETTER_C = chr(67)
LATIN_CAPITAL_LETTER_D = chr(68)
LATIN_CAPITAL_LETTER_E = chr(69)
LATIN_CAPITAL_LETTER_F = chr(70)
LATIN_CAPITAL_LETTER_G = chr(71)
LATIN_CAPITAL_LETTER_H = chr(72)
LATIN_CAPITAL_LETTER_I = chr(73)
LATIN_CAPITAL_LETTER_J = chr(74)
LATIN_CAPITAL_LETTER_K = chr(75)
LATIN_CAPITAL_LETTER_L = chr(76)
LATIN_CAPITAL_LETTER_M = chr(77)
LATIN_CAPITAL_LETTER_N = chr(78)
LATIN_CAPITAL_LETTER_O = chr(79)
LATIN_CAPITAL_LETTER_P = chr(80)
LATIN_CAPITAL_LETTER_Q = chr(81)
LATIN_CAPITAL_LETTER_R = chr(82)
LATIN_CAPITAL_LETTER_S = chr(83)
LATIN_CAPITAL_LETTER_T = chr(84)
LATIN_CAPITAL_LETTER_U = chr(85)
LATIN_CAPITAL_LETTER_V = chr(86)
LATIN_CAPITAL_LETTER_W = chr(87)
LATIN_CAPITAL_LETTER_X = chr(88)
LATIN_CAPITAL_LETTER_Y = chr(89)
LATIN_CAPITAL_LETTER_Z = chr(90)
LEFT_SQUARE_BRACKET = chr(91)
REVERSE_SOLIDUS = chr(92)
RIGHT_SQUARE_BRACKET = chr(93)
CIRCUMFLEX_ACCENT = chr(94)
LOW_LINE = chr(95)
GRAVE_ACCENT = chr(96)
LATIN_SMALL_LETTER_A = chr(97)
LATIN_SMALL_LETTER_B = chr(98)
LATIN_SMALL_LETTER_C = chr(99)
LATIN_SMALL_LETTER_D = chr(100)
LATIN_SMALL_LETTER_E = chr(101)
LATIN_SMALL_LETTER_F = chr(102)
LATIN_SMALL_LETTER_G = chr(103)
LATIN_SMALL_LETTER_H = chr(104)
LATIN_SMALL_LETTER_I = chr(105)
LATIN_SMALL_LETTER_J = chr(106)
LATIN_SMALL_LETTER_K = chr(107)
LATIN_SMALL_LETTER_L = chr(108)
LATIN_SMALL_LETTER_M = chr(109)
LATIN_SMALL_LETTER_N = chr(110)
LATIN_SMALL_LETTER_O = chr(111)
LATIN_SMALL_LETTER_P = chr(112)
LATIN_SMALL_LETTER_Q = chr(113)
LATIN_SMALL_LETTER_R = chr(114)
LATIN_SMALL_LETTER_S = chr(115)
LATIN_SMALL_LETTER_T = chr(116)
LATIN_SMALL_LETTER_U = chr(117)
LATIN_SMALL_LETTER_V = chr(118)
LATIN_SMALL_LETTER_W = chr(119)
LATIN_SMALL_LETTER_X = chr(120)
LATIN_SMALL_LETTER_Y = chr(121)
LATIN_SMALL_LETTER_Z = chr(122)
LEFT_CURLY_BRACKET = chr(123)
VERTICAL_LINE = chr(124)
RIGHT_CURLY_BRACKET = chr(125)
TILDE = chr(126)
DELETE = chr(127)

########################################################################

FUNCTION = string(
    LESS_THAN_SIGN,
    LATIN_SMALL_LETTER_F,
    LATIN_SMALL_LETTER_U,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_N,
    SPACE,
)

INIT = string(
    LOW_LINE,
    LOW_LINE,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_T,
    LOW_LINE,
    LOW_LINE,
)

KEY = string(
    COLON,
    COLON,
)

PYTHON_EXTENSION = string(
    FULL_STOP,
    LATIN_SMALL_LETTER_P,
    LATIN_SMALL_LETTER_Y,
)

########################################################################

APPLICATION = string(
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_P,
    LATIN_SMALL_LETTER_P,
    LATIN_SMALL_LETTER_L,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_N,
)

BLENDER = string(
    LATIN_SMALL_LETTER_B,
    LATIN_SMALL_LETTER_L,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_D,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_R,
)

CELESTINE = string(
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_L,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_S,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_E,
)

CONFIGURATION = string(
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_F,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_G,
    LATIN_SMALL_LETTER_U,
    LATIN_SMALL_LETTER_R,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_N,
)

DIRECTORY = string(
    LATIN_SMALL_LETTER_D,
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_R,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_O,
    LATIN_SMALL_LETTER_R,
    LATIN_SMALL_LETTER_Y,
)

INTERFACE = string(
    LATIN_SMALL_LETTER_I,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_T,
    LATIN_SMALL_LETTER_E,
    LATIN_SMALL_LETTER_R,
    LATIN_SMALL_LETTER_F,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_E,
)

LANGUAGE = string(
    LATIN_SMALL_LETTER_L,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_N,
    LATIN_SMALL_LETTER_G,
    LATIN_SMALL_LETTER_U,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_G,
    LATIN_SMALL_LETTER_E,
)

PACKAGE = string(
    LATIN_SMALL_LETTER_P,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_C,
    LATIN_SMALL_LETTER_K,
    LATIN_SMALL_LETTER_A,
    LATIN_SMALL_LETTER_G,
    LATIN_SMALL_LETTER_E,
)

########################################################################

VERSION_NUMBER = "2025.2.17"
